pub struct MarketLocationProperties {
pub market_location_property: MarketLocationProperty,
pub execution_time_from: String,
pub execution_time_until: Option<String>,
}Expand description
Property of a market location valid for a specific time slice.
Fields
market_location_property: MarketLocationPropertyexecution_time_from: Stringexecution_time_until: Option<String>Trait Implementations
Sourceimpl Clone for MarketLocationProperties
impl Clone for MarketLocationProperties
Sourcefn clone(&self) -> MarketLocationProperties
fn clone(&self) -> MarketLocationProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MarketLocationProperties
impl Debug for MarketLocationProperties
Sourceimpl<'de> Deserialize<'de> for MarketLocationProperties
impl<'de> Deserialize<'de> for MarketLocationProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MarketLocationProperties
impl PartialEq for MarketLocationProperties
Sourcefn eq(&self, other: &MarketLocationProperties) -> bool
fn eq(&self, other: &MarketLocationProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MarketLocationProperties
impl Serialize for MarketLocationProperties
impl StructuralPartialEq for MarketLocationProperties